anvio home

# Welcome to anvi'server

An interactive tree visualization platfrom (very unstable alpha version)

Previous Next

### What is anvi'server?

Anvi'server is an open-source work environment for data visualization. Anvi'server is a part of a larger project, anvi'o. Anvi'o is an an advanced analysis and visualization platform for 'omics data. We designed anvi'o mainly for microbiologists who routinely use high-throughput sequencing to study microbial life in complex environments. It uses an extensible visualization approach to distill multiple dimensions of information about each contig into a single display, offering a dynamic and unified work environment for data exploration, manipulation, and reporting. When we realized that the interactive interface of anvi'o can be useful for ad hoc visualization tasks, we decided to create anvi'server. Anvi'server is open source, and a part of the anvi'o codebase.

### Upload, Analyze, Share

Using this platform you can create an account and upload your data files to create publication-quality figures in minutes using anvi'o's highly-configurable interface options, and you can share your visualizations privately with your colleagues, or make them publicly available in a read-only format.

© 2016 Anvi'o Project.